[Libreoffice-commits] core.git: sw/source

Miklos Vajna vmiklos at collabora.co.uk
Tue Nov 10 05:13:07 PST 2015


 sw/source/filter/ww8/attributeoutputbase.hxx |    6 +--
 sw/source/filter/ww8/docxattributeoutput.cxx |   34 +++++++++----------
 sw/source/filter/ww8/docxattributeoutput.hxx |    6 +--
 sw/source/filter/ww8/docxsdrexport.cxx       |    8 ++--
 sw/source/filter/ww8/docxsdrexport.hxx       |   10 ++---
 sw/source/filter/ww8/rtfattributeoutput.cxx  |   18 +++++-----
 sw/source/filter/ww8/rtfattributeoutput.hxx  |    4 +-
 sw/source/filter/ww8/rtfsdrexport.cxx        |    4 +-
 sw/source/filter/ww8/writerhelper.cxx        |   47 ++++++++++++++-------------
 sw/source/filter/ww8/writerhelper.hxx        |   30 ++++++++---------
 sw/source/filter/ww8/wrtw8esh.cxx            |   24 ++++++-------
 sw/source/filter/ww8/wrtw8nds.cxx            |   30 ++++++++---------
 sw/source/filter/ww8/wrtww8.cxx              |    4 +-
 sw/source/filter/ww8/wrtww8.hxx              |   36 ++++++++++----------
 sw/source/filter/ww8/wrtww8gr.cxx            |   24 ++++++-------
 sw/source/filter/ww8/ww8atr.cxx              |   14 ++++----
 sw/source/filter/ww8/ww8attributeoutput.hxx  |    2 -
 sw/source/filter/ww8/ww8par.cxx              |    6 +--
 18 files changed, 155 insertions(+), 152 deletions(-)

New commits:
commit 87cd02c4dab1e5b333b0c153b432dc7d9f47338d
Author: Miklos Vajna <vmiklos at collabora.co.uk>
Date:   Tue Nov 10 14:11:54 2015 +0100

    sw: rename sw::Frame in the WW8 filter to ww8::Frame
    
    This way it's more clear that sw::FrameClient has nothing to do with
    sw::Frame, also later renaming SwFrm to SwFrame won't cause confusion
    about why do we have both sw::Frame and SwFrame.
    
    Change-Id: I87c4d199d418c77fdbb600fc388c8b9f026cb0fa

diff --git a/sw/source/filter/ww8/attributeoutputbase.hxx b/sw/source/filter/ww8/attributeoutputbase.hxx
index 3fe18ea..308a247 100644
--- a/sw/source/filter/ww8/attributeoutputbase.hxx
+++ b/sw/source/filter/ww8/attributeoutputbase.hxx
@@ -129,7 +129,7 @@ namespace rtl { class OUString; }
 
 class MSWordExportBase;
 
-namespace sw { class Frame; }
+namespace ww8 { class Frame; }
 
 namespace msword {
     const sal_uInt8 ColumnBreak = 0xE;
@@ -365,7 +365,7 @@ protected:
     static void GetNumberPara( OUString& rStr, const SwField& rField );
 
     /// Output frames - the implementation.
-    virtual void OutputFlyFrame_Impl( const sw::Frame& rFormat, const Point& rNdTopLeft ) = 0;
+    virtual void OutputFlyFrame_Impl( const ww8::Frame& rFormat, const Point& rNdTopLeft ) = 0;
 
     /// Sfx item Sfx item RES_CHRATR_CASEMAP
     virtual void CharCaseMap( const SvxCaseMapItem& ) = 0;
@@ -643,7 +643,7 @@ public:
     void OutputStyleItemSet( const SfxItemSet& rSet, bool bDeep, bool bTestForDefault );
 
     /// Output frames.
-    void OutputFlyFrame( const sw::Frame& rFormat );
+    void OutputFlyFrame( const ww8::Frame& rFormat );
 
     void GetTablePageSize
     ( ww8::WW8TableNodeInfoInner * pTableTextNodeInfoInner,
diff --git a/sw/source/filter/ww8/docxattributeoutput.cxx b/sw/source/filter/ww8/docxattributeoutput.cxx
index cfd0484..bcfbf61 100644
--- a/sw/source/filter/ww8/docxattributeoutput.cxx
+++ b/sw/source/filter/ww8/docxattributeoutput.cxx
@@ -450,7 +450,7 @@ void DocxAttributeOutput::EndParagraph( ww8::WW8TableNodeInfoInner::Pointer_t pT
 {
     // write the paragraph properties + the run, already in the correct order
     m_pSerializer->mergeTopMarks(Tag_StartParagraph_2);
-    std::vector<  std::shared_ptr <sw::Frame> > aFramePrTextbox;
+    std::vector<  std::shared_ptr <ww8::Frame> > aFramePrTextbox;
     // Write the anchored frame if any
     // Word can't handle nested text boxes, so write them on the same level.
     ++m_nTextFrameLevel;
@@ -463,7 +463,7 @@ void DocxAttributeOutput::EndParagraph( ww8::WW8TableNodeInfoInner::Pointer_t pT
         for (size_t nIndex = 0; nIndex < m_aFramesOfParagraph.size(); ++nIndex)
         {
             m_bParagraphFrameOpen = true;
-            sw::Frame aFrame = m_aFramesOfParagraph[nIndex];
+            ww8::Frame aFrame = m_aFramesOfParagraph[nIndex];
             const SwFrameFormat& rFrameFormat = aFrame.GetFrameFormat();
 
             if (!TextBoxIsFramePr(rFrameFormat) || m_bWritingHeaderFooter)
@@ -526,8 +526,8 @@ void DocxAttributeOutput::EndParagraph( ww8::WW8TableNodeInfoInner::Pointer_t pT
             }
             else
             {
-                std::shared_ptr<sw::Frame>  pFramePr;
-                pFramePr.reset(new sw::Frame(aFrame));
+                std::shared_ptr<ww8::Frame>  pFramePr;
+                pFramePr.reset(new ww8::Frame(aFrame));
                 aFramePrTextbox.push_back(pFramePr);
             }
         }
@@ -585,7 +585,7 @@ void DocxAttributeOutput::EndParagraph( ww8::WW8TableNodeInfoInner::Pointer_t pT
     // Write framePr
     if(!aFramePrTextbox.empty())
     {
-        for (std::vector< std::shared_ptr<sw::Frame> > ::iterator it = aFramePrTextbox.begin() ; it != aFramePrTextbox.end(); ++it)
+        for (std::vector< std::shared_ptr<ww8::Frame> > ::iterator it = aFramePrTextbox.begin() ; it != aFramePrTextbox.end(); ++it)
         {
             DocxTableExportContext aTableExportContext;
             pushToTableExportContext(aTableExportContext);
@@ -4934,13 +4934,13 @@ void DocxAttributeOutput::WritePostponedDMLDrawing()
     m_pPostponedOLEs.reset(pPostponedOLEs.release());
 }
 
-void DocxAttributeOutput::OutputFlyFrame_Impl( const sw::Frame &rFrame, const Point& rNdTopLeft )
+void DocxAttributeOutput::OutputFlyFrame_Impl( const ww8::Frame &rFrame, const Point& rNdTopLeft )
 {
     m_pSerializer->mark(Tag_OutputFlyFrame);
 
     switch ( rFrame.GetWriterType() )
     {
-        case sw::Frame::eGraphic:
+        case ww8::Frame::eGraphic:
             {
                 const SdrObject* pSdrObj = rFrame.GetFrameFormat().FindRealSdrObject();
                 const SwNode *pNode = rFrame.GetContent();
@@ -4960,7 +4960,7 @@ void DocxAttributeOutput::OutputFlyFrame_Impl( const sw::Frame &rFrame, const Po
                 }
             }
             break;
-        case sw::Frame::eDrawing:
+        case ww8::Frame::eDrawing:
             {
                 const SdrObject* pSdrObj = rFrame.GetFrameFormat().FindRealSdrObject();
                 if ( pSdrObj )
@@ -5011,7 +5011,7 @@ void DocxAttributeOutput::OutputFlyFrame_Impl( const sw::Frame &rFrame, const Po
                 }
             }
             break;
-        case sw::Frame::eTextBox:
+        case ww8::Frame::eTextBox:
             {
                 // If this is a TextBox of a shape, then ignore: it's handled in WriteTextBox().
                 if (m_rExport.SdrExporter().isTextBox(rFrame.GetFrameFormat()))
@@ -5035,11 +5035,11 @@ void DocxAttributeOutput::OutputFlyFrame_Impl( const sw::Frame &rFrame, const Po
                 if( !bDuplicate )
                 {
                     m_bPostponedProcessingFly = true ;
-                    m_aFramesOfParagraph.push_back(sw::Frame(rFrame));
+                    m_aFramesOfParagraph.push_back(ww8::Frame(rFrame));
                 }
             }
             break;
-        case sw::Frame::eOle:
+        case ww8::Frame::eOle:
             {
                 const SwFrameFormat &rFrameFormat = rFrame.GetFrameFormat();
                 const SdrObject *pSdrObj = rFrameFormat.FindRealSdrObject();
@@ -5052,7 +5052,7 @@ void DocxAttributeOutput::OutputFlyFrame_Impl( const sw::Frame &rFrame, const Po
                 }
             }
             break;
-        case sw::Frame::eFormControl:
+        case ww8::Frame::eFormControl:
             {
                 const SdrObject* pObject = rFrame.GetFrameFormat().FindRealSdrObject();
                 m_aPostponedFormControls.push_back(pObject);
@@ -5060,9 +5060,9 @@ void DocxAttributeOutput::OutputFlyFrame_Impl( const sw::Frame &rFrame, const Po
             }
             break;
         default:
-            OSL_TRACE( "TODO DocxAttributeOutput::OutputFlyFrame_Impl( const sw::Frame& rFrame, const Point& rNdTopLeft ) - frame type '%s'\n",
-                    rFrame.GetWriterType() == sw::Frame::eTextBox? "eTextBox":
-                    ( rFrame.GetWriterType() == sw::Frame::eOle? "eOle": "???" ) );
+            OSL_TRACE( "TODO DocxAttributeOutput::OutputFlyFrame_Impl( const ww8::Frame& rFrame, const Point& rNdTopLeft ) - frame type '%s'\n",
+                    rFrame.GetWriterType() == ww8::Frame::eTextBox? "eTextBox":
+                    ( rFrame.GetWriterType() == ww8::Frame::eOle? "eOle": "???" ) );
             break;
     }
 
@@ -5181,7 +5181,7 @@ void DocxAttributeOutput::WriteTextBox(uno::Reference<drawing::XShape> xShape)
 
     SwFrameFormat* pTextBox = SwTextBoxHelper::findTextBox(xShape);
     const SwPosition* pAnchor = pTextBox->GetAnchor().GetContentAnchor();
-    sw::Frame aFrame(*pTextBox, *pAnchor);
+    ww8::Frame aFrame(*pTextBox, *pAnchor);
     m_rExport.SdrExporter().writeDMLTextFrame(&aFrame, m_anchorId++, /*bTextBoxOnly=*/true);
 
     popFromTableExportContext(aTableExportContext);
@@ -5194,7 +5194,7 @@ void DocxAttributeOutput::WriteVMLTextBox(uno::Reference<drawing::XShape> xShape
 
     SwFrameFormat* pTextBox = SwTextBoxHelper::findTextBox(xShape);
     const SwPosition* pAnchor = pTextBox->GetAnchor().GetContentAnchor();
-    sw::Frame aFrame(*pTextBox, *pAnchor);
+    ww8::Frame aFrame(*pTextBox, *pAnchor);
     m_rExport.SdrExporter().writeVMLTextFrame(&aFrame, /*bTextBoxOnly=*/true);
 
     popFromTableExportContext(aTableExportContext);
diff --git a/sw/source/filter/ww8/docxattributeoutput.hxx b/sw/source/filter/ww8/docxattributeoutput.hxx
index 53042bc..1dbddc4 100644
--- a/sw/source/filter/ww8/docxattributeoutput.hxx
+++ b/sw/source/filter/ww8/docxattributeoutput.hxx
@@ -450,7 +450,7 @@ private:
 protected:
 
     /// Output frames - the implementation.
-    virtual void OutputFlyFrame_Impl( const sw::Frame& rFormat, const Point& rNdTopLeft ) override;
+    virtual void OutputFlyFrame_Impl( const ww8::Frame& rFormat, const Point& rNdTopLeft ) override;
 
     /// Sfx item Sfx item RES_CHRATR_CASEMAP
     virtual void CharCaseMap( const SvxCaseMapItem& rCaseMap ) override;
@@ -798,7 +798,7 @@ private:
     /// The current table helper
     std::unique_ptr<SwWriteTable> m_xTableWrt;
 
-    sw::Frame* m_pCurrentFrame;
+    ww8::Frame* m_pCurrentFrame;
 
     bool m_bParagraphOpened;
     bool m_bParagraphFrameOpen;
@@ -810,7 +810,7 @@ private:
     // beginning of the next paragraph
     DocxColBreakStatus m_nColBreakStatus;
 
-    std::vector<sw::Frame> m_aFramesOfParagraph;
+    std::vector<ww8::Frame> m_aFramesOfParagraph;
     sal_Int32 m_nTextFrameLevel;
 
     // close of hyperlink needed
diff --git a/sw/source/filter/ww8/docxsdrexport.cxx b/sw/source/filter/ww8/docxsdrexport.cxx
index c4581b1..436a4c7 100644
--- a/sw/source/filter/ww8/docxsdrexport.cxx
+++ b/sw/source/filter/ww8/docxsdrexport.cxx
@@ -109,7 +109,7 @@ void lclMovePositionWithRotation(awt::Point& aPos, const Size& rSize, sal_Int64
 
 }
 
-ExportDataSaveRestore::ExportDataSaveRestore(DocxExport& rExport, sal_uLong nStt, sal_uLong nEnd, sw::Frame* pParentFrame)
+ExportDataSaveRestore::ExportDataSaveRestore(DocxExport& rExport, sal_uLong nStt, sal_uLong nEnd, ww8::Frame* pParentFrame)
     : m_rExport(rExport)
 {
     m_rExport.SaveData(nStt, nEnd);
@@ -1292,7 +1292,7 @@ void DocxSdrExport::writeDiagram(const SdrObject* sdrObject, const SwFrameFormat
     }
 }
 
-void DocxSdrExport::writeOnlyTextOfFrame(sw::Frame* pParentFrame)
+void DocxSdrExport::writeOnlyTextOfFrame(ww8::Frame* pParentFrame)
 {
     const SwFrameFormat& rFrameFormat = pParentFrame->GetFrameFormat();
     const SwNodeIndex* pNodeIndex = rFrameFormat.GetContent().GetContentIdx();
@@ -1358,7 +1358,7 @@ void DocxSdrExport::writeBoxItemLine(const SvxBoxItem& rBox)
     pFS->endElementNS(XML_a, XML_ln);
 }
 
-void DocxSdrExport::writeDMLTextFrame(sw::Frame* pParentFrame, int nAnchorId, bool bTextBoxOnly)
+void DocxSdrExport::writeDMLTextFrame(ww8::Frame* pParentFrame, int nAnchorId, bool bTextBoxOnly)
 {
     bool bDMLAndVMLDrawingOpen = m_pImpl->m_bDMLAndVMLDrawingOpen;
     m_pImpl->m_bDMLAndVMLDrawingOpen = true;
@@ -1635,7 +1635,7 @@ void DocxSdrExport::writeDMLTextFrame(sw::Frame* pParentFrame, int nAnchorId, bo
     m_pImpl->m_bDMLAndVMLDrawingOpen = bDMLAndVMLDrawingOpen;
 }
 
-void DocxSdrExport::writeVMLTextFrame(sw::Frame* pParentFrame, bool bTextBoxOnly)
+void DocxSdrExport::writeVMLTextFrame(ww8::Frame* pParentFrame, bool bTextBoxOnly)
 {
     bool bDMLAndVMLDrawingOpen = m_pImpl->m_bDMLAndVMLDrawingOpen;
     m_pImpl->m_bDMLAndVMLDrawingOpen = true;
diff --git a/sw/source/filter/ww8/docxsdrexport.hxx b/sw/source/filter/ww8/docxsdrexport.hxx
index a16c3d3..4e935b1 100644
--- a/sw/source/filter/ww8/docxsdrexport.hxx
+++ b/sw/source/filter/ww8/docxsdrexport.hxx
@@ -30,7 +30,7 @@ class Point;
 class SdrObject;
 class SvxBoxItem;
 
-namespace sw
+namespace ww8
 {
 class Frame;
 }
@@ -45,7 +45,7 @@ class ExportDataSaveRestore
 private:
     DocxExport& m_rExport;
 public:
-    ExportDataSaveRestore(DocxExport& rExport, sal_uLong nStt, sal_uLong nEnd, sw::Frame* pParentFrame);
+    ExportDataSaveRestore(DocxExport& rExport, sal_uLong nStt, sal_uLong nEnd, ww8::Frame* pParentFrame);
     ~ExportDataSaveRestore();
 };
 
@@ -101,13 +101,13 @@ public:
                           css::uno::Reference<css::io::XOutputStream> xOutStream, const OUString& sGrabBagProperyName,
                           int nAnchorId);
     /// Writes text frame in DML format.
-    void writeDMLTextFrame(sw::Frame* pParentFrame, int nAnchorId, bool bTextBoxOnly = false);
+    void writeDMLTextFrame(ww8::Frame* pParentFrame, int nAnchorId, bool bTextBoxOnly = false);
     /// Writes text frame in VML format.
-    void writeVMLTextFrame(sw::Frame* pParentFrame, bool bTextBoxOnly = false);
+    void writeVMLTextFrame(ww8::Frame* pParentFrame, bool bTextBoxOnly = false);
     /// Is this a standalone TextFrame, or used as a TextBox of a shape?
     bool isTextBox(const SwFrameFormat& rFrameFormat);
     /// Writes text from Textbox for <w:framePr>
-    void writeOnlyTextOfFrame(sw::Frame* pParentFrame);
+    void writeOnlyTextOfFrame(ww8::Frame* pParentFrame);
     /// Writes the drawingML <a:ln> markup of a box item.
     void writeBoxItemLine(const SvxBoxItem& rBoxItem);
 };
diff --git a/sw/source/filter/ww8/rtfattributeoutput.cxx b/sw/source/filter/ww8/rtfattributeoutput.cxx
index 47f63db..2f2e35d 100644
--- a/sw/source/filter/ww8/rtfattributeoutput.cxx
+++ b/sw/source/filter/ww8/rtfattributeoutput.cxx
@@ -1773,7 +1773,7 @@ void lcl_TextFrameRelativeSize(std::vector< std::pair<OString, OString> >& rFlyP
 
 }
 
-void RtfAttributeOutput::writeTextFrame(const sw::Frame& rFrame, bool bTextBox)
+void RtfAttributeOutput::writeTextFrame(const ww8::Frame& rFrame, bool bTextBox)
 {
     RtfStringBuffer aRunText;
     if (bTextBox)
@@ -1840,14 +1840,14 @@ void RtfAttributeOutput::writeTextFrame(const sw::Frame& rFrame, bool bTextBox)
     }
 }
 
-void RtfAttributeOutput::OutputFlyFrame_Impl(const sw::Frame& rFrame, const Point& /*rNdTopLeft*/)
+void RtfAttributeOutput::OutputFlyFrame_Impl(const ww8::Frame& rFrame, const Point& /*rNdTopLeft*/)
 {
     const SwNode* pNode = rFrame.GetContent();
     const SwGrfNode* pGrfNode = pNode ? pNode->GetGrfNode() : nullptr;
 
     switch (rFrame.GetWriterType())
     {
-    case sw::Frame::eTextBox:
+    case ww8::Frame::eTextBox:
     {
         // If this is a TextBox of a shape, then ignore: it's handled in RtfSdrExport::StartShape().
         if (m_rExport.SdrExporter().isTextBox(rFrame.GetFrameFormat()))
@@ -1897,7 +1897,7 @@ void RtfAttributeOutput::OutputFlyFrame_Impl(const sw::Frame& rFrame, const Poin
         m_rExport.Strm().WriteCharPtr(SAL_NEWLINE_STRING);
     }
     break;
-    case sw::Frame::eGraphic:
+    case ww8::Frame::eGraphic:
         if (!rFrame.IsInline())
         {
             m_rExport.m_pParentFrame = &rFrame;
@@ -1913,7 +1913,7 @@ void RtfAttributeOutput::OutputFlyFrame_Impl(const sw::Frame& rFrame, const Poin
         if (pGrfNode)
             m_aRunText.append(dynamic_cast<const SwFlyFrameFormat*>(&rFrame.GetFrameFormat()), pGrfNode);
         break;
-    case sw::Frame::eDrawing:
+    case ww8::Frame::eDrawing:
     {
         const SdrObject* pSdrObj = rFrame.GetFrameFormat().FindRealSdrObject();
         if (pSdrObj)
@@ -1947,7 +1947,7 @@ void RtfAttributeOutput::OutputFlyFrame_Impl(const sw::Frame& rFrame, const Poin
         }
     }
     break;
-    case sw::Frame::eFormControl:
+    case ww8::Frame::eFormControl:
     {
         const SwFrameFormat& rFrameFormat = rFrame.GetFrameFormat();
         const SdrObject* pObject = rFrameFormat.FindRealSdrObject();
@@ -2147,7 +2147,7 @@ void RtfAttributeOutput::OutputFlyFrame_Impl(const sw::Frame& rFrame, const Poin
         m_aRun->append('}');
     }
     break;
-    case sw::Frame::eOle:
+    case ww8::Frame::eOle:
     {
         const SwFrameFormat& rFrameFormat = rFrame.GetFrameFormat();
         const SdrObject* pSdrObj = rFrameFormat.FindRealSdrObject();
@@ -3908,8 +3908,8 @@ void RtfAttributeOutput::FlyFrameGraphic(const SwFlyFrameFormat* pFlyFrameFormat
     aRendered.Width() = rS.GetWidth();
     aRendered.Height() = rS.GetHeight();
 
-    sw::Frame* pFrame = nullptr;
-    for (sw::FrameIter it = m_rExport.m_aFrames.begin(); it != m_rExport.m_aFrames.end(); ++it)
+    ww8::Frame* pFrame = nullptr;
+    for (ww8::FrameIter it = m_rExport.m_aFrames.begin(); it != m_rExport.m_aFrames.end(); ++it)
     {
         if (pFlyFrameFormat == &it->GetFrameFormat())
         {
diff --git a/sw/source/filter/ww8/rtfattributeoutput.hxx b/sw/source/filter/ww8/rtfattributeoutput.hxx
index 403c797..1a882fd 100644
--- a/sw/source/filter/ww8/rtfattributeoutput.hxx
+++ b/sw/source/filter/ww8/rtfattributeoutput.hxx
@@ -219,7 +219,7 @@ public:
 
 protected:
     /// Output frames - the implementation.
-    virtual void OutputFlyFrame_Impl(const sw::Frame& rFormat, const Point& rNdTopLeft) override;
+    virtual void OutputFlyFrame_Impl(const ww8::Frame& rFormat, const Point& rNdTopLeft) override;
 
     /// Sfx item Sfx item RES_CHRATR_CASEMAP
     virtual void CharCaseMap(const SvxCaseMapItem& rCaseMap) override;
@@ -636,7 +636,7 @@ public:
     void BulletDefinition(int nId, const Graphic& rGraphic, Size aSize) override;
 
     /// Handles just the {\shptxt ...} part of a shape export.
-    void writeTextFrame(const sw::Frame& rFrame, bool bTextBox = false);
+    void writeTextFrame(const ww8::Frame& rFrame, bool bTextBox = false);
 };
 
 #endif // INCLUDED_SW_SOURCE_FILTER_WW8_RTFATTRIBUTEOUTPUT_HXX
diff --git a/sw/source/filter/ww8/rtfsdrexport.cxx b/sw/source/filter/ww8/rtfsdrexport.cxx
index 364d1a6..cacf2e8 100644
--- a/sw/source/filter/ww8/rtfsdrexport.cxx
+++ b/sw/source/filter/ww8/rtfsdrexport.cxx
@@ -514,8 +514,8 @@ sal_Int32 RtfSdrExport::StartShape()
     {
         if (SwFrameFormat* pTextBox = SwTextBoxHelper::findTextBox(pShape))
         {
-            sw::Frame* pFrame = nullptr;
-            for (sw::FrameIter it = m_rExport.m_aFrames.begin(); it != m_rExport.m_aFrames.end(); ++it)
+            ww8::Frame* pFrame = nullptr;
+            for (ww8::FrameIter it = m_rExport.m_aFrames.begin(); it != m_rExport.m_aFrames.end(); ++it)
             {
                 if (pTextBox == &it->GetFrameFormat())
                 {
diff --git a/sw/source/filter/ww8/writerhelper.cxx b/sw/source/filter/ww8/writerhelper.cxx
index 8b15791..c5dda9f 100644
--- a/sw/source/filter/ww8/writerhelper.cxx
+++ b/sw/source/filter/ww8/writerhelper.cxx
@@ -110,15 +110,15 @@ namespace
     }
 
     /*
-     Utility to convert a SwPosFlyFrms into a simple vector of sw::Frames
+     Utility to convert a SwPosFlyFrms into a simple vector of ww8::Frames
 
-     The crucial thing is that a sw::Frame always has an anchor which
+     The crucial thing is that a ww8::Frame always has an anchor which
      points to some content in the document. This is a requirement of exporting
      to Word
     */
-    sw::Frames SwPosFlyFrmsToFrames(const SwPosFlyFrms &rFlys)
+    ww8::Frames SwPosFlyFrmsToFrames(const SwPosFlyFrms &rFlys)
     {
-        sw::Frames aRet;
+        ww8::Frames aRet;
 
         for(SwPosFlyFrms::const_iterator aIter(rFlys.begin()); aIter != rFlys.end(); ++aIter)
         {
@@ -130,7 +130,7 @@ namespace
                 // so set a dummy position and fix it in UpdateFramePositions
                 SwPosition const dummy(SwNodeIndex(
                             const_cast<SwNodes&>(pAnchor->nNode.GetNodes())));
-                aRet.push_back(sw::Frame(rEntry, dummy));
+                aRet.push_back(ww8::Frame(rEntry, dummy));
             }
             else
             {
@@ -141,27 +141,27 @@ namespace
                     aPos.nContent.Assign(pTextNd, 0);
                 }
 
-                aRet.push_back(sw::Frame(rEntry, aPos));
+                aRet.push_back(ww8::Frame(rEntry, aPos));
             }
         }
         return aRet;
     }
 
     //Utility to test if a frame is anchored at a given node index
-    class anchoredto: public std::unary_function<const sw::Frame&, bool>
+    class anchoredto: public std::unary_function<const ww8::Frame&, bool>
     {
     private:
         sal_uLong mnNode;
     public:
         explicit anchoredto(sal_uLong nNode) : mnNode(nNode) {}
-        bool operator()(const sw::Frame &rFrame) const
+        bool operator()(const ww8::Frame &rFrame) const
         {
             return (mnNode == rFrame.GetPosition().nNode.GetNode().GetIndex());
         }
     };
 }
 
-namespace sw
+namespace ww8
 {
     //For i120928,size conversion before exporting graphic of bullet
     Frame::Frame(const Graphic &rGrf, const SwPosition &rPos)
@@ -268,7 +268,10 @@ namespace sw
     {
         mbIsInline = true;
     }
+}
 
+namespace sw
+{
     namespace hack
     {
 
@@ -417,7 +420,7 @@ namespace sw
         }
         //SetLayer boilerplate end
 
-        void GetPoolItems(const SfxItemSet &rSet, PoolItems &rItems, bool bExportParentItemSet )
+        void GetPoolItems(const SfxItemSet &rSet, ww8::PoolItems &rItems, bool bExportParentItemSet )
         {
             if( bExportParentItemSet )
             {
@@ -443,10 +446,10 @@ namespace sw
             }
         }
 
-        const SfxPoolItem *SearchPoolItems(const PoolItems &rItems,
+        const SfxPoolItem *SearchPoolItems(const ww8::PoolItems &rItems,
             sal_uInt16 eType)
         {
-            sw::cPoolItemIter aIter = rItems.find(eType);
+            ww8::cPoolItemIter aIter = rItems.find(eType);
             if (aIter != rItems.end())
                 return aIter->second;
             return nullptr;
@@ -467,10 +470,10 @@ namespace sw
             }
         }
 
-        ParaStyles GetParaStyles(const SwDoc &rDoc)
+        ww8::ParaStyles GetParaStyles(const SwDoc &rDoc)
         {
-            ParaStyles aStyles;
-            typedef ParaStyles::size_type mysizet;
+            ww8::ParaStyles aStyles;
+            typedef ww8::ParaStyles::size_type mysizet;
 
             const SwTextFormatColls *pColls = rDoc.GetTextFormatColls();
             mysizet nCount = pColls ? pColls->size() : 0;
@@ -510,7 +513,7 @@ namespace sw
         }
 
         // #i98791# - adjust sorting algorithm
-        void SortByAssignedOutlineStyleListLevel(ParaStyles &rStyles)
+        void SortByAssignedOutlineStyleListLevel(ww8::ParaStyles &rStyles)
         {
             std::sort(rStyles.begin(), rStyles.end(), outlinecmp());
         }
@@ -519,16 +522,16 @@ namespace sw
            Utility to extract FlyFormats from a document, potentially from a
            selection.
            */
-        Frames GetFrames(const SwDoc &rDoc, SwPaM *pPaM /*, bool bAll*/)
+        ww8::Frames GetFrames(const SwDoc &rDoc, SwPaM *pPaM /*, bool bAll*/)
         {
             SwPosFlyFrms aFlys(rDoc.GetAllFlyFormats(pPaM, true));
-            sw::Frames aRet(SwPosFlyFrmsToFrames(aFlys));
+            ww8::Frames aRet(SwPosFlyFrmsToFrames(aFlys));
             return aRet;
         }
 
-        void UpdateFramePositions(Frames & rFrames)
+        void UpdateFramePositions(ww8::Frames & rFrames)
         {
-            for (Frame & rFrame : rFrames)
+            for (ww8::Frame & rFrame : rFrames)
             {
                 SwFormatAnchor const& rAnchor = rFrame.GetFrameFormat().GetAnchor();
                 if (SwPosition const*const pAnchor = rAnchor.GetContentAnchor())
@@ -542,9 +545,9 @@ namespace sw
             }
         }
 
-        Frames GetFramesInNode(const Frames &rFrames, const SwNode &rNode)
+        ww8::Frames GetFramesInNode(const ww8::Frames &rFrames, const SwNode &rNode)
         {
-            Frames aRet;
+            ww8::Frames aRet;
             my_copy_if(rFrames.begin(), rFrames.end(),
                 std::back_inserter(aRet), anchoredto(rNode.GetIndex()));
             return aRet;
diff --git a/sw/source/filter/ww8/wrtw8esh.cxx b/sw/source/filter/ww8/wrtw8esh.cxx
index fa39c6d..2da78d5 100644
--- a/sw/source/filter/ww8/wrtw8esh.cxx
+++ b/sw/source/filter/ww8/wrtw8esh.cxx
@@ -664,7 +664,7 @@ bool RTLDrawingsHack(long &rLeft, long /*nWidth*/,
 }
 
 bool WW8Export::MiserableRTLFrameFormatHack(SwTwips &rLeft, SwTwips &rRight,
-    const sw::Frame &rFrameFormat)
+    const ww8::Frame &rFrameFormat)
 {
     //Require nasty bidi swap
     if (FRMDIR_HORI_RIGHT_TOP != m_pDoc->GetTextDirection(rFrameFormat.GetPosition()))
@@ -677,8 +677,8 @@ bool WW8Export::MiserableRTLFrameFormatHack(SwTwips &rLeft, SwTwips &rRight,
     const SwFormatHoriOrient& rHOr = rFrameFormat.GetFrameFormat().GetHoriOrient();
 
     bool bRet = false;
-    sw::Frame::WriterSource eSource = rFrameFormat.GetWriterType();
-    if (eSource == sw::Frame::eDrawing || eSource == sw::Frame::eFormControl)
+    ww8::Frame::WriterSource eSource = rFrameFormat.GetWriterType();
+    if (eSource == ww8::Frame::eDrawing || eSource == ww8::Frame::eFormControl)
     {
         if (RTLDrawingsHack(rLeft, nWidth, rHOr.GetHoriOrient(),
             rHOr.GetRelationOrient(), nPageLeft, nPageRight, nPageSize))
@@ -724,7 +724,7 @@ void PlcDrawObj::WritePlc( WW8Export& rWrt ) const
         for (aIter = maDrawObjs.begin(); aIter < aEnd; ++aIter)
         {
             // write the fspa-struct
-            const sw::Frame &rFrameFormat = aIter->maContent;
+            const ww8::Frame &rFrameFormat = aIter->maContent;
             const SwFrameFormat &rFormat = rFrameFormat.GetFrameFormat();
             const SdrObject* pObj = rFormat.FindRealSdrObject();
 
@@ -934,7 +934,7 @@ DrawObj& DrawObj::operator=(const DrawObj& rOther)
     return *this;
 }
 
-bool PlcDrawObj::Append( WW8Export& rWrt, WW8_CP nCp, const sw::Frame& rFormat,
+bool PlcDrawObj::Append( WW8Export& rWrt, WW8_CP nCp, const ww8::Frame& rFormat,
     const Point& rNdTopLeft )
 {
     bool bRet = false;
@@ -1025,7 +1025,7 @@ sal_uInt32 WW8Export::GetSdrOrdNum( const SwFrameFormat& rFormat ) const
     return nOrdNum;
 }
 
-void WW8Export::AppendFlyInFlys(const sw::Frame& rFrameFormat,
+void WW8Export::AppendFlyInFlys(const ww8::Frame& rFrameFormat,
     const Point& rNdTopLeft)
 {
     OSL_ENSURE(!m_pEscher, "der EscherStream wurde schon geschrieben!");
@@ -2318,20 +2318,20 @@ SwEscherEx::SwEscherEx(SvStream* pStrm, WW8Export& rWW8Wrt)
             OSL_ENSURE(pObj, "impossible");
             if (!pObj)
                 continue;
-            const sw::Frame &rFrame = pObj->maContent;
+            const ww8::Frame &rFrame = pObj->maContent;
             const SwFrameFormat& rFormat = rFrame.GetFrameFormat();
 
             switch (rFrame.GetWriterType())
             {
-                case sw::Frame::eTextBox:
-                case sw::Frame::eOle:
-                case sw::Frame::eGraphic:
+                case ww8::Frame::eTextBox:
+                case ww8::Frame::eOle:
+                case ww8::Frame::eGraphic:
                     nBorderThick = WriteFlyFrm(*pObj, nShapeId, aSorted);
                     break;
-                case sw::Frame::eFormControl:
+                case ww8::Frame::eFormControl:
                     WriteOCXControl(rFormat, nShapeId = GenerateShapeId());
                     break;
-                case sw::Frame::eDrawing:
+                case ww8::Frame::eDrawing:
                 {
                     aWinwordAnchoring.SetAnchoring(rFormat);
                     const SdrObject* pSdrObj = rFormat.FindRealSdrObject();
diff --git a/sw/source/filter/ww8/wrtw8nds.cxx b/sw/source/filter/ww8/wrtw8nds.cxx
index a04012b..32a90d1 100644
--- a/sw/source/filter/ww8/wrtw8nds.cxx
+++ b/sw/source/filter/ww8/wrtw8nds.cxx
@@ -159,10 +159,10 @@ MSWordAttrIter::~MSWordAttrIter()
 }
 
 class sortswflys :
-    public std::binary_function<const sw::Frame&, const sw::Frame&, bool>
+    public std::binary_function<const ww8::Frame&, const ww8::Frame&, bool>
 {
 public:
-    bool operator()(const sw::Frame &rOne, const sw::Frame &rTwo) const
+    bool operator()(const ww8::Frame &rOne, const ww8::Frame &rTwo) const
     {
         return rOne.GetPosition() < rTwo.GetPosition();
     }
@@ -211,7 +211,7 @@ SwWW8AttrIter::SwWW8AttrIter(MSWordExportBase& rWr, const SwTextNode& rTextNd) :
     if (rWr.m_bInWriteEscher)
     {
         std::for_each(maFlyFrms.begin(), maFlyFrms.end(),
-            std::mem_fun_ref(&sw::Frame::ForceTreatAsInline));
+            std::mem_fun_ref(&ww8::Frame::ForceTreatAsInline));
     }
 
     maFlyIter = maFlyFrms.begin();
@@ -414,7 +414,7 @@ void SwWW8AttrIter::OutAttr( sal_Int32 nSwPos, bool bRuby )
 
     //The additional hard formatting properties that affect this range in the
     //paragraph
-    sw::PoolItems aRangeItems;
+    ww8::PoolItems aRangeItems;
     if (const SwpHints* pTextAttrs = rNd.GetpSwpHints())
     {
         for( size_t i = 0; i < pTextAttrs->Count(); ++i )
@@ -465,14 +465,14 @@ void SwWW8AttrIter::OutAttr( sal_Int32 nSwPos, bool bRuby )
     if ( pCharFormatItem )
         ClearOverridesFromSet( *pCharFormatItem, aExportSet );
 
-    sw::PoolItems aExportItems;
+    ww8::PoolItems aExportItems;
     GetPoolItems( aExportSet, aExportItems, false );
 
     if( rNd.GetpSwpHints() == nullptr )
         m_rExport.SetCurItemSet(&aExportSet);
 
-    sw::cPoolItemIter aEnd = aRangeItems.end();
-    for ( sw::cPoolItemIter aI = aRangeItems.begin(); aI != aEnd; ++aI )
+    ww8::cPoolItemIter aEnd = aRangeItems.end();
+    for ( ww8::cPoolItemIter aI = aRangeItems.begin(); aI != aEnd; ++aI )
     {
         if ( !bRuby || !lcl_isFontsizeItem( *aI->second ) )
             aExportItems[aI->first] = aI->second;
@@ -530,7 +530,7 @@ bool SwWW8AttrIter::IsWatermarkFrame()
 
 bool SwWW8AttrIter::IsAnchorLinkedToThisNode( sal_uLong nNodePos )
 {
-    sw::FrameIter aTmpFlyIter = maFlyIter ;
+    ww8::FrameIter aTmpFlyIter = maFlyIter ;
 
     while ( aTmpFlyIter != maFlyFrms.end() )
     {
@@ -551,11 +551,11 @@ FlyProcessingState SwWW8AttrIter::OutFlys(sal_Int32 nSwPos)
 {
     // collection point to first gather info about all of the potentially linked textboxes: to be analyzed later.
     OUString sLinkChainName;
-    sw::FrameIter linkedTextboxesIter = maFlyIter;
+    ww8::FrameIter linkedTextboxesIter = maFlyIter;
     while ( linkedTextboxesIter != maFlyFrms.end() )
     {
         uno::Reference< drawing::XShape > xShape;
-        sw::Frame xFrame = *linkedTextboxesIter;
+        ww8::Frame xFrame = *linkedTextboxesIter;
         const SdrObject* pSdrObj = xFrame.GetFrameFormat().FindRealSdrObject();
         if( pSdrObj )
             xShape.set(const_cast<SdrObject*>(pSdrObj)->getUnoShape(), uno::UNO_QUERY);
@@ -2894,7 +2894,7 @@ void WW8Export::AppendSection( const SwPageDesc *pPageDesc, const SwSectionForma
 
 // Flys
 
-void WW8AttributeOutput::OutputFlyFrame_Impl( const sw::Frame& rFormat, const Point& rNdTopLeft )
+void WW8AttributeOutput::OutputFlyFrame_Impl( const ww8::Frame& rFormat, const Point& rNdTopLeft )
 {
     const SwFrameFormat &rFrameFormat = rFormat.GetFrameFormat();
     const SwFormatAnchor& rAnch = rFrameFormat.GetAnchor();
@@ -2903,8 +2903,8 @@ void WW8AttributeOutput::OutputFlyFrame_Impl( const sw::Frame& rFormat, const Po
 
     if (rFormat.IsInline())
     {
-        sw::Frame::WriterSource eType = rFormat.GetWriterType();
-        if ((eType == sw::Frame::eGraphic) || (eType == sw::Frame::eOle))
+        ww8::Frame::WriterSource eType = rFormat.GetWriterType();
+        if ((eType == ww8::Frame::eGraphic) || (eType == ww8::Frame::eOle))
             bUseEscher = false;
         else
             bUseEscher = true;
@@ -2913,7 +2913,7 @@ void WW8AttributeOutput::OutputFlyFrame_Impl( const sw::Frame& rFormat, const Po
          A special case for converting some inline form controls to form fields
          when in winword 8+ mode
         */
-        if (bUseEscher && (eType == sw::Frame::eFormControl))
+        if (bUseEscher && (eType == ww8::Frame::eFormControl))
         {
             if ( m_rWW8Export.MiserableFormFieldExportHack( rFrameFormat ) )
                 return ;
@@ -2988,7 +2988,7 @@ void WW8AttributeOutput::OutputFlyFrame_Impl( const sw::Frame& rFormat, const Po
     }
 }
 
-void AttributeOutputBase::OutputFlyFrame( const sw::Frame& rFormat )
+void AttributeOutputBase::OutputFlyFrame( const ww8::Frame& rFormat )
 {
     if ( !rFormat.GetContentNode() )
         return;
diff --git a/sw/source/filter/ww8/wrtww8.cxx b/sw/source/filter/ww8/wrtww8.cxx
index 59effda..bf659bc 100644
--- a/sw/source/filter/ww8/wrtww8.cxx
+++ b/sw/source/filter/ww8/wrtww8.cxx
@@ -1459,7 +1459,7 @@ void WW8Export::ExportGrfBullet(const SwTextNode& rNd)
         AppendBookmark(aPicBullets);
         for (int i = 0; i < nCount; i++)
         {
-            sw::Frame aFrame(*(m_vecBulletPic[i]), aPos);
+            ww8::Frame aFrame(*(m_vecBulletPic[i]), aPos);
             OutGrfBullets(aFrame);
         }
         AppendBookmark(aPicBullets);
@@ -1467,7 +1467,7 @@ void WW8Export::ExportGrfBullet(const SwTextNode& rNd)
 }
 
 static sal_uInt8 nAttrMagicIdx = 0;
-void WW8Export::OutGrfBullets(const sw::Frame & rFrame)
+void WW8Export::OutGrfBullets(const ww8::Frame & rFrame)
 {
     if ( !m_pGrf || !m_pChpPlc || !pO )
         return;
diff --git a/sw/source/filter/ww8/wrtww8.hxx b/sw/source/filter/ww8/wrtww8.hxx
index 1d835b0..78d5875 100644
--- a/sw/source/filter/ww8/wrtww8.hxx
+++ b/sw/source/filter/ww8/wrtww8.hxx
@@ -338,14 +338,14 @@ class DrawObj
 public:
     WW8_CP mnCp;                // CP-Pos of references
     sal_uInt32 mnShapeId;       // ShapeId for the SwFrameFormats
-    sw::Frame maContent;          // the frame itself
+    ww8::Frame maContent;          // the frame itself
     Point maParentPos;          // Points
     sal_Int32 mnThick;          // Border Thicknesses
     short mnDirection;          // If BiDi or not
     unsigned int mnHdFtIndex;   // 0 for main text, +1 for each subsequent
                                 // msword hd/ft
 
-    DrawObj(const sw::Frame &rContent, WW8_CP nCp, Point aParentPos, short nDir,
+    DrawObj(const ww8::Frame &rContent, WW8_CP nCp, Point aParentPos, short nDir,
             unsigned int nHdFtIndex)
         : mnCp(nCp), mnShapeId(0), maContent(rContent), maParentPos(aParentPos),
         mnThick(0), mnDirection(nDir), mnHdFtIndex(nHdFtIndex) {}
@@ -370,7 +370,7 @@ protected:
 public:
     PlcDrawObj() {}
     void WritePlc( WW8Export& rWrt ) const;
-    bool Append( WW8Export&, WW8_CP nCp, const sw::Frame& rFormat,
+    bool Append( WW8Export&, WW8_CP nCp, const ww8::Frame& rFormat,
         const Point& rNdTopLeft );
     int size() { return maDrawObjs.size(); };
     DrawObjVector &GetObjArr() { return maDrawObjs; }
@@ -432,7 +432,7 @@ struct MSWordSaveData
     ww::bytes* pOOld;                ///< WW8Export only
     SwPaM* pOldPam, *pOldEnd;
     sal_uLong nOldStart, nOldEnd;
-    const sw::Frame* pOldFlyFormat;
+    const ww8::Frame* pOldFlyFormat;
     const SwPageDesc* pOldPageDesc;
 
     bool bOldWriteAll : 1;          ///< WW8Export only
@@ -481,7 +481,7 @@ public:
 public:
     /* implicit bookmark vector containing pairs of node indexes and bookmark names */
     std::vector<aBookmarkPair> m_aImplicitBookmarks;
-    sw::Frames m_aFrames;             // The floating frames in this document
+    ww8::Frames m_aFrames;             // The floating frames in this document
     const SwPageDesc *m_pAktPageDesc;
     bool m_bPrevTextNodeIsEmpty;
     WW8_WrPlcPn* m_pPapPlc;
@@ -503,7 +503,7 @@ public:
     bool m_bLinkedTextboxesHelperInitialized = false;
     sal_Int32 m_nLinkedTextboxesChainId=0;
 
-    const sw::Frame *m_pParentFrame; // If set we are exporting content inside
+    const ww8::Frame *m_pParentFrame; // If set we are exporting content inside
                                     // a frame, e.g. a graphic node
 
     Point* m_pFlyOffset;              // for adjusting of character-bound Fly in the Writer,
@@ -588,7 +588,7 @@ public:
     void WriteSpecialText( sal_uLong nStart, sal_uLong nEnd, sal_uInt8 nTTyp );
 
     /// Export the pool items to attributes (through an attribute output class).
-    void ExportPoolItemsToCHP( sw::PoolItems &rItems, sal_uInt16 nScript );
+    void ExportPoolItemsToCHP( ww8::PoolItems &rItems, sal_uInt16 nScript );
 
     /// Return the numeric id of the numbering rule
     sal_uInt16 GetId( const SwNumRule& rNumRule );
@@ -1014,7 +1014,7 @@ public:
     const SvxBrushItem* GetCurrentPageBgBrush() const;
     SvxBrushItem TrueFrameBgBrush(const SwFrameFormat &rFlyFormat) const;
 
-    void AppendFlyInFlys(const sw::Frame& rFrameFormat, const Point& rNdTopLeft);
+    void AppendFlyInFlys(const ww8::Frame& rFrameFormat, const Point& rNdTopLeft);
     void WriteOutliner(const OutlinerParaObject& rOutliner, sal_uInt8 nTyp);
     void WriteSdrTextObj(const SdrTextObj& rObj, sal_uInt8 nTyp);
 
@@ -1028,7 +1028,7 @@ public:
 
     void StartCommentOutput( const OUString& rName );
     void EndCommentOutput(   const OUString& rName );
-    void OutGrf(const sw::Frame &rFrame);
+    void OutGrf(const ww8::Frame &rFrame);
     bool TestOleNeedsGraphic(const SwAttrSet& rSet, tools::SvRef<SotStorage> xOleStg,
         tools::SvRef<SotStorage> xObjStg, OUString &rStorageName, SwOLENode *pOLENd);
 
@@ -1038,7 +1038,7 @@ public:
     virtual void AppendAnnotationMarks( const SwTextNode& rNd, sal_Int32 nAktPos, sal_Int32 nLen ) override;
 
     virtual void ExportGrfBullet(const SwTextNode& rNd) override;
-    void OutGrfBullets(const sw::Frame &rFrame);
+    void OutGrfBullets(const ww8::Frame &rFrame);
 
     void MoveFieldMarks(WW8_CP nFrom, WW8_CP nTo);
 
@@ -1097,7 +1097,7 @@ public:
 
     /// Nasty swap for bidi if necessary
     bool MiserableRTLFrameFormatHack(SwTwips &rLeft, SwTwips &rRight,
-        const sw::Frame &rFrameFormat);
+        const ww8::Frame &rFrameFormat);
 
     void InsUInt16( sal_uInt16 n )      { SwWW8Writer::InsUInt16( *pO, n ); }
     void InsUInt32( sal_uInt32 n )      { SwWW8Writer::InsUInt32( *pO, n ); }
@@ -1327,12 +1327,12 @@ public:
 class GraphicDetails
 {
 public:
-    sw::Frame maFly;                // surrounding FlyFrms
+    ww8::Frame maFly;                // surrounding FlyFrms
     sal_uLong mnPos;                // FilePos of the graphics
     sal_uInt16 mnWid;               // Width of the graphics
     sal_uInt16 mnHei;               // Height of the graphics
 
-    GraphicDetails(const sw::Frame &rFly, sal_uInt16 nWid, sal_uInt16 nHei)
+    GraphicDetails(const ww8::Frame &rFly, sal_uInt16 nWid, sal_uInt16 nHei)
         : maFly(rFly), mnPos(0), mnWid(nWid), mnHei(nHei)
     {}
     GraphicDetails& operator=(const GraphicDetails& rOther);
@@ -1357,12 +1357,12 @@ private:
     typedef std::vector<GraphicDetails>::iterator myiter;
     sal_uInt16 mnIdx;       // index in file positions
 
-    static void WritePICFHeader(SvStream& rStrm, const sw::Frame &rFly,
+    static void WritePICFHeader(SvStream& rStrm, const ww8::Frame &rFly,
             sal_uInt16 mm, sal_uInt16 nWidth, sal_uInt16 nHeight,
             const SwAttrSet* pAttrSet = nullptr);
     void WriteGraphicNode(SvStream& rStrm, const GraphicDetails &rItem);
     void WriteGrfFromGrfNode(SvStream& rStrm, const SwGrfNode &rNd,
-        const sw::Frame &rFly, sal_uInt16 nWidth, sal_uInt16 nHeight);
+        const ww8::Frame &rFly, sal_uInt16 nWidth, sal_uInt16 nHeight);
 
     static void WritePICBulletFHeader(SvStream& rStrm, const Graphic &rGrf, sal_uInt16 mm, sal_uInt16 nWidth, sal_uInt16 nHeight);
     void WriteGrfForBullet(SvStream& rStrm,  const Graphic &rGrf, sal_uInt16 nWidth, sal_uInt16 nHeight);
@@ -1371,7 +1371,7 @@ private:
     SwWW8WrGrf& operator=(const SwWW8WrGrf&) = delete;
 public:
     explicit SwWW8WrGrf( WW8Export& rW ) : rWrt( rW ), mnIdx( 0 ) {}
-    void Insert(const sw::Frame &rFly);
+    void Insert(const ww8::Frame &rFly);
     void Write();
     sal_uLong GetFPos()
         { return (mnIdx < maDetails.size()) ? maDetails[mnIdx++].mnPos : 0; }
@@ -1465,8 +1465,8 @@ private:
 
     const SwFormatDrop &mrSwFormatDrop;
 
-    sw::Frames maFlyFrms;     // #i2916#
-    sw::FrameIter maFlyIter;
+    ww8::Frames maFlyFrms;     // #i2916#
+    ww8::FrameIter maFlyIter;
 
     sal_Int32 SearchNext( sal_Int32 nStartPos );
 
diff --git a/sw/source/filter/ww8/wrtww8gr.cxx b/sw/source/filter/ww8/wrtww8gr.cxx
index bf252de..be42e4f 100644
--- a/sw/source/filter/ww8/wrtww8gr.cxx
+++ b/sw/source/filter/ww8/wrtww8gr.cxx
@@ -358,13 +358,13 @@ void WW8Export::OutputLinkedOLE( const OUString& rOleId )
     }
 }
 
-void WW8Export::OutGrf(const sw::Frame &rFrame)
+void WW8Export::OutGrf(const ww8::Frame &rFrame)
 {
     //Added for i120568,the hyperlink info within a graphic whose anchor type is "As character"
     //will be exported to ensure the fidelity
     const SwFormatURL& rURL = rFrame.GetFrameFormat().GetAttrSet().GetURL();
     bool bURLStarted = false;
-    if( !rURL.GetURL().isEmpty() && rFrame.GetWriterType() == sw::Frame::eGraphic)
+    if( !rURL.GetURL().isEmpty() && rFrame.GetWriterType() == ww8::Frame::eGraphic)
     {
         bURLStarted = true;
         m_pAttrOutput->StartURL( rURL.GetURL(), rURL.GetTargetFrameName() );
@@ -490,7 +490,7 @@ GraphicDetails& GraphicDetails::operator=(const GraphicDetails &rOther)
     return *this;
 }
 
-void SwWW8WrGrf::Insert(const sw::Frame &rFly)
+void SwWW8WrGrf::Insert(const ww8::Frame &rFly)
 {
     const Size aSize( rFly.GetLayoutSize() );
     const sal_uInt16 nWidth = static_cast< sal_uInt16 >(aSize.Width());
@@ -498,7 +498,7 @@ void SwWW8WrGrf::Insert(const sw::Frame &rFly)
     maDetails.push_back(GraphicDetails(rFly, nWidth, nHeight));
 }
 
-void SwWW8WrGrf::WritePICFHeader(SvStream& rStrm, const sw::Frame &rFly,
+void SwWW8WrGrf::WritePICFHeader(SvStream& rStrm, const ww8::Frame &rFly,
     sal_uInt16 mm, sal_uInt16 nWidth, sal_uInt16 nHeight, const SwAttrSet* pAttrSet)
 {
     sal_Int16 nXSizeAdd = 0, nYSizeAdd = 0;
@@ -654,7 +654,7 @@ void SwWW8WrGrf::WritePICFHeader(SvStream& rStrm, const sw::Frame &rFly,
 }
 
 void SwWW8WrGrf::WriteGrfFromGrfNode(SvStream& rStrm, const SwGrfNode &rGrfNd,
-    const sw::Frame &rFly, sal_uInt16 nWidth, sal_uInt16 nHeight)
+    const ww8::Frame &rFly, sal_uInt16 nWidth, sal_uInt16 nHeight)
 {
     if (rGrfNd.IsLinkedFile())     // Linked File
     {
@@ -780,10 +780,10 @@ void SwWW8WrGrf::WriteGraphicNode(SvStream& rStrm, const GraphicDetails &rItem)
     sal_uInt16 nHeight = rItem.mnHei;
     sal_uInt32 nPos = rStrm.Tell();         // store start of graphic
 
-    const sw::Frame &rFly = rItem.maFly;
+    const ww8::Frame &rFly = rItem.maFly;
     switch (rFly.GetWriterType())
     {
-        case sw::Frame::eGraphic:
+        case ww8::Frame::eGraphic:
         {
             const SwNode *pNode = rItem.maFly.GetContent();
             const SwGrfNode *pNd = pNode ? pNode->GetGrfNode() : nullptr;
@@ -793,7 +793,7 @@ void SwWW8WrGrf::WriteGraphicNode(SvStream& rStrm, const GraphicDetails &rItem)
         }
         break;
         //For i120928,add branch to export graphic of bullet
-        case sw::Frame::eBulletGrf:
+        case ww8::Frame::eBulletGrf:
         {
             if (rItem.maFly.HasGraphic())
             {
@@ -803,7 +803,7 @@ void SwWW8WrGrf::WriteGraphicNode(SvStream& rStrm, const GraphicDetails &rItem)
         }
         break;
 
-        case sw::Frame::eOle:
+        case ww8::Frame::eOle:
         {
             const SwNode *pNode = rItem.maFly.GetContent();
             const SwOLENode *pNd = pNode ? pNode->GetOLENode() : nullptr;
@@ -846,9 +846,9 @@ void SwWW8WrGrf::WriteGraphicNode(SvStream& rStrm, const GraphicDetails &rItem)
             }
         }
         break;
-        case sw::Frame::eDrawing:
-        case sw::Frame::eTextBox:
-        case sw::Frame::eFormControl:
+        case ww8::Frame::eDrawing:
+        case ww8::Frame::eTextBox:
+        case ww8::Frame::eFormControl:
             /*
             #i3958# We only export an empty dummy picture frame here, this is
             what word does the escher export should contain an anchored to
diff --git a/sw/source/filter/ww8/ww8atr.cxx b/sw/source/filter/ww8/ww8atr.cxx
index 9f0ca17..86061fc 100644
--- a/sw/source/filter/ww8/ww8atr.cxx
+++ b/sw/source/filter/ww8/ww8atr.cxx
@@ -204,10 +204,10 @@ bool WW8Export::CollapseScriptsforWordOk( sal_uInt16 nScript, sal_uInt16 nWhich
 
 //  Hilfsroutinen fuer Styles
 
-void MSWordExportBase::ExportPoolItemsToCHP( sw::PoolItems &rItems, sal_uInt16 nScript )
+void MSWordExportBase::ExportPoolItemsToCHP( ww8::PoolItems &rItems, sal_uInt16 nScript )
 {
-    sw::cPoolItemIter aEnd = rItems.end();
-    for ( sw::cPoolItemIter aI = rItems.begin(); aI != aEnd; ++aI )
+    ww8::cPoolItemIter aEnd = rItems.end();
+    for ( ww8::cPoolItemIter aI = rItems.begin(); aI != aEnd; ++aI )
     {
         const SfxPoolItem *pItem = aI->second;
         sal_uInt16 nWhich = pItem->Which();
@@ -266,14 +266,14 @@ void MSWordExportBase::OutputItemSet( const SfxItemSet& rSet, bool bPapFormat, b
             }
         }
 
-        sw::PoolItems aItems;
+        ww8::PoolItems aItems;
         GetPoolItems( rSet, aItems, bExportParentItemSet );
         if ( bChpFormat )
             ExportPoolItemsToCHP(aItems, nScript);
         if ( bPapFormat )
         {
-            sw::cPoolItemIter aEnd = aItems.end();
-            for ( sw::cPoolItemIter aI = aItems.begin(); aI != aEnd; ++aI )
+            ww8::cPoolItemIter aEnd = aItems.end();
+            for ( ww8::cPoolItemIter aI = aItems.begin(); aI != aEnd; ++aI )
             {
                 pItem = aI->second;
                 sal_uInt16 nWhich = pItem->Which();
@@ -2925,7 +2925,7 @@ void AttributeOutputBase::TextFlyContent( const SwFormatFlyCnt& rFlyContent )
         aLayPos = pTextNd->FindLayoutRect( false, &aLayPos ).Pos();
 
         SwPosition aPos( *pTextNd );
-        sw::Frame aFrm( *rFlyContent.GetFrameFormat(), aPos );
+        ww8::Frame aFrm( *rFlyContent.GetFrameFormat(), aPos );
 
         OutputFlyFrame_Impl( aFrm, aLayPos );
     }
diff --git a/sw/source/filter/ww8/ww8attributeoutput.hxx b/sw/source/filter/ww8/ww8attributeoutput.hxx
index 4c830704..f3c0b9a 100644
--- a/sw/source/filter/ww8/ww8attributeoutput.hxx
+++ b/sw/source/filter/ww8/ww8attributeoutput.hxx
@@ -200,7 +200,7 @@ public:
 
 protected:
     /// Output frames - the implementation.
-    void OutputFlyFrame_Impl( const sw::Frame& rFormat, const Point& rNdTopLeft ) override;
+    void OutputFlyFrame_Impl( const ww8::Frame& rFormat, const Point& rNdTopLeft ) override;
 
     /// Sfx item Sfx item RES_CHRATR_CASEMAP
     virtual void CharCaseMap( const SvxCaseMapItem& ) override;
diff --git a/sw/source/filter/ww8/ww8par.cxx b/sw/source/filter/ww8/ww8par.cxx
index d4ea09f..1bf4914 100644
--- a/sw/source/filter/ww8/ww8par.cxx
+++ b/sw/source/filter/ww8/ww8par.cxx
@@ -5799,10 +5799,10 @@ void SwWW8ImplReader::SetOutlineStyles()
     sal_uInt16 nOutlineStyleListLevelWithAssignment = 0;
     if (!m_bNewDoc)
     {
-        sw::ParaStyles aOutLined(sw::util::GetParaStyles(m_rDoc));
+        ww8::ParaStyles aOutLined(sw::util::GetParaStyles(m_rDoc));
         sw::util::SortByAssignedOutlineStyleListLevel(aOutLined);
-        sw::ParaStyles::reverse_iterator aEnd = aOutLined.rend();
-        for ( sw::ParaStyles::reverse_iterator aIter = aOutLined.rbegin(); aIter < aEnd; ++aIter)
+        ww8::ParaStyles::reverse_iterator aEnd = aOutLined.rend();
+        for ( ww8::ParaStyles::reverse_iterator aIter = aOutLined.rbegin(); aIter < aEnd; ++aIter)
         {
             if ((*aIter)->IsAssignedToListLevelOfOutlineStyle())
                 nOutlineStyleListLevelWithAssignment |= 1 << (*aIter)->GetAssignedOutlineStyleLevel();


More information about the Libreoffice-commits mailing list
diff --git a/sw/source/filter/ww8/writerhelper.hxx b/sw/source/filter/ww8/writerhelper.hxx
index 7538cb3..7a840e9 100644
--- a/sw/source/filter/ww8/writerhelper.hxx
+++ b/sw/source/filter/ww8/writerhelper.hxx
@@ -61,7 +61,7 @@ namespace sw
     }
 }
 
-namespace sw
+namespace ww8
 {
     /// STL container of Paragraph Styles (SwTextFormatColl)
     typedef std::vector<SwTextFormatColl *> ParaStyles;
@@ -76,10 +76,10 @@ namespace sw
 
         In word all frames are effectively anchored to character or as
         character. This is nice and simple, writer is massively complex in this
-        area, so this sw::Frame simplifies matters by providing a single unified
+        area, so this ww8::Frame simplifies matters by providing a single unified
         view of the multitute of elements in writer and their differing quirks.
 
-        A sw::Frame wraps a writer frame and is guaranteed to have a suitable
+        A ww8::Frame wraps a writer frame and is guaranteed to have a suitable
         anchor position available from it. It hides much of the needless
         complexity of the multitude of floating/inline elements in writer, it...
 
@@ -154,7 +154,7 @@ namespace sw
 
             There are a variety of circumstances where word cannot have
             anything except inline elements, e.g. inside frames. So its easier
-            to force this sw::Frame into behaving as one, instead of special
+            to force this ww8::Frame into behaving as one, instead of special
             casing export code all over the place.
 
         */
@@ -169,10 +169,10 @@ namespace sw
         const Graphic &GetGraphic() const { return maGrf; }
         bool HasGraphic() const { return mbForBullet; }
 
         /** Does this sw::Frame refer to the same writer content as another
 
          @return
-         if the two sw::Frames are handling the same writer frame
+         if the two ww8::Frames are handling the same writer frame
         */
         bool RefersToSameFrameAs(const Frame &rOther) const
         {
@@ -442,7 +442,7 @@ namespace sw
             @author
             <a href="mailto:cmc at openoffice.org">Caolán McNamara</a>
         */
-        ParaStyles GetParaStyles(const SwDoc &rDoc);
+        ww8::ParaStyles GetParaStyles(const SwDoc &rDoc);
 
         /** Get a Paragraph Style which fits a given name
 
@@ -495,7 +495,7 @@ namespace sw
             @author
             <a href="mailto:cmc at openoffice.org">Caolán McNamara</a>
         */
-        void SortByAssignedOutlineStyleListLevel(ParaStyles &rStyles);
+        void SortByAssignedOutlineStyleListLevel(ww8::ParaStyles &rStyles);
 
         /** Get the SfxPoolItems of a SfxItemSet
 
@@ -512,12 +512,12 @@ namespace sw
             @author
             <a href="mailto:cmc at openoffice.org">Caolán McNamara</a>
         */
-        void GetPoolItems(const SfxItemSet &rSet, PoolItems &rItems, bool bExportParentItemSet );
+        void GetPoolItems(const SfxItemSet &rSet, ww8::PoolItems &rItems, bool bExportParentItemSet );
 
-        const SfxPoolItem *SearchPoolItems(const PoolItems &rItems,
+        const SfxPoolItem *SearchPoolItems(const ww8::PoolItems &rItems,
             sal_uInt16 eType);
 
-        template<class T> const T* HasItem(const sw::PoolItems &rItems,
+        template<class T> const T* HasItem(const ww8::PoolItems &rItems,
             sal_uInt16 eType)
         {
             return item_cast<T>(SearchPoolItems(rItems, eType));
@@ -551,7 +551,7 @@ namespace sw
             e.g. Page Anchored elements will not be. For the winword export we
             need them to have something to be anchored to. So this method
             returns all the floating elements in a document as a STL container
-            of sw::Frames which are guaranteed to have an appropriate anchor.
+            of ww8::Frames which are guaranteed to have an appropriate anchor.
 
             @param rDoc
             The SwDoc document to get the styles from
@@ -565,10 +565,10 @@ namespace sw
             @author
             <a href="mailto:cmc at openoffice.org">Caolán McNamara</a>
         */
-        Frames GetFrames(const SwDoc &rDoc, SwPaM *pPaM = nullptr);
+        ww8::Frames GetFrames(const SwDoc &rDoc, SwPaM *pPaM = nullptr);
 
         /** fix up frame positions, must be called after SetRedlineMode */
-        void UpdateFramePositions(Frames & rFrames);
+        void UpdateFramePositions(ww8::Frames & rFrames);
 
         /** Get the Frames anchored to a given node
 
@@ -585,7 +585,7 @@ namespace sw
             @author
             <a href="mailto:cmc at openoffice.org">Caolán McNamara</a>
         */
-        Frames GetFramesInNode(const Frames &rFrames, const SwNode &rNode);
+        ww8::Frames GetFramesInNode(const ww8::Frames &rFrames, const SwNode &rNode);
 
         /** Get the Numbering Format used on a paragraph
 
@@ -169,10 +169,10 @@ namespace sw
         bool HasGraphic() const { return mbForBullet; }
 
-        /** Does this sw::Frame refer to the same writer content as another
+        /** Does this ww8::Frame refer to the same writer content as another
 
          @return